@@ -250,3 +250,12 @@ void on_mni_suggest (GtkMenuItem *menuitem, gpointer user_data);
 void on_bt_close_current_doc (GtkButton *button, gpointer user_data);
 void on_mni_hide_error_marks (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_spellcheck_def (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_split_by (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_split_after_delimiter (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_replace_in_place (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_repeat_the_last (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_mark_on_regexp (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_test2 (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_find_in_files (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_mark_lines_with_fuzzy_nontrans (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_lorem_ipsum (GtkMenuItem *menuitem, gpointer user_data);
