@@ -53,9 +53,15 @@ GtkWidget* create_wnd_imgviewer (gchar *f)
 
   g_signal_connect (G_OBJECT (wnd_imgviewer), "key_press_event", G_CALLBACK (win_key_handler), wnd_imgviewer);
 
+/*
   g_signal_connect ((gpointer) wnd_imgviewer, "destroy_event",
                     G_CALLBACK (gtk_false),
                     NULL);
+*/
+    g_signal_connect ((gpointer) wnd_imgviewer, "delete_event",
+                    G_CALLBACK (gtk_false),
+                    NULL);
+
 
   GtkWidget *image = gtk_image_new_from_file (f);
   gtk_container_add (GTK_CONTAINER (wnd_imgviewer), image);
@@ -91,7 +97,7 @@ void image_browser_init (void)
 
 void image_browser_done (void)
 {
-  glist_strings_free (gl_thumbs);  
+  glist_strings_free (gl_thumbs);
 }
 
 
@@ -106,7 +112,7 @@ static gint destroy_event (GtkWidget *widget, GdkEventAny *event, gpointer data)
 GtkWidget* create_image_browser (gchar *dir)
 {
   GtkWidget *tvb;
-  gchar *filename;     
+  gchar *filename;
   gchar *utf;
 
   GtkWidget *label;
@@ -137,7 +143,7 @@ GtkWidget* create_image_browser (gchar *dir)
   gtk_widget_show (vbox1);
   gtk_container_add (GTK_CONTAINER (wnd), vbox1);
 
-  cb_imgplane_mode_sw = tea_checkbox (vbox1, _("Insert tags"), confile.implane_ins_image);                                            
+  cb_imgplane_mode_sw = tea_checkbox (vbox1, _("Insert tags"), confile.implane_ins_image);
   gtk_tooltips_set_tip (tooltips,
                         cb_imgplane_mode_sw,
                         _("Insert the tag rather than view image"),
@@ -151,10 +157,10 @@ GtkWidget* create_image_browser (gchar *dir)
 
   GtkWidget *vbox2 = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (vbox2);
-  
+
   gtk_scrolled_window_add_with_viewport (sw, vbox2);
 
-  GtkWidget *pb = gtk_progress_bar_new ();    
+  GtkWidget *pb = gtk_progress_bar_new ();
   gtk_widget_show (pb);
   gtk_box_pack_start (vbox1, pb, FALSE, FALSE, UI_PACKFACTOR);
 
@@ -165,30 +171,30 @@ GtkWidget* create_image_browser (gchar *dir)
   if (gl_thumbs)
      {
       len = g_list_length (gl_thumbs) - 1;
-            
+
       GList *t = g_list_first (gl_thumbs);
       while (t)
            {
             if (is_image (t->data))
-               { 
+               {
                 while (gtk_events_pending ())
                     gtk_main_iteration ();
-                      
+
                 val = ((gdouble)++c / (gdouble)(len - 0.999));
                 if (val > 1.0)
-                   val = 0.0;  
-                gtk_progress_bar_set_fraction (pb, val) ;
-                 
+                   val = 0.0;
+                gtk_progress_bar_set_fraction (pb, val);
+
                 button = gtk_button_new ();
                 g_signal_connect (button, "clicked", G_CALLBACK (cb_on_pic_button_click), t->data);
 
                 tvb = gtk_vbox_new (FALSE, UI_PACKFACTOR);
                 gtk_widget_show (tvb);
                 gtk_container_add (GTK_CONTAINER (button), tvb);
-              
-                uri = g_strconcat ("file://", t->data, NULL); 
-                md5_get_digest (uri, strlen (uri), digest);     
-                
+
+                uri = g_strconcat ("file://", t->data, NULL);
+                md5_get_digest (uri, strlen (uri), digest);
+
                 md5sum = md5_digest_to_text (digest);
 
                 if (md5sum)
@@ -199,19 +205,19 @@ GtkWidget* create_image_browser (gchar *dir)
                    else  
                        pixbuf = gdk_pixbuf_new_from_file_at_size (t->data, confile.thumb_width, confile.thumb_height, NULL); 
                   }
-                else   
+                else
                     pixbuf = gdk_pixbuf_new_from_file_at_size (t->data, confile.thumb_width, confile.thumb_height, NULL); 
-                 
-                g_free (uri); 
+
+                g_free (uri);
                 g_free (md5sum);
                 g_free (thumb_filename);
-                
+
                 image = gtk_image_new_from_pixbuf (pixbuf);
                 gtk_widget_show (image);
-                
-                gtk_box_pack_start (tvb, image, FALSE, FALSE, UI_PACKFACTOR);        
 
-                filename = g_path_get_basename (t->data); 
+                gtk_box_pack_start (tvb, image, FALSE, FALSE, UI_PACKFACTOR);
+
+                filename = g_path_get_basename (t->data);
                 utf = get_8_filename (filename);
                 label = gtk_label_new (utf);
 
@@ -219,10 +225,10 @@ GtkWidget* create_image_browser (gchar *dir)
                 g_free (utf);
 
                 gtk_widget_show (label);
-                gtk_box_pack_start (tvb, label, FALSE, FALSE, UI_PACKFACTOR);         
-       
+                gtk_box_pack_start (tvb, label, FALSE, FALSE, UI_PACKFACTOR);
+
                 gtk_widget_show (button);
-                gtk_box_pack_start (vbox2, button, FALSE, FALSE, UI_PACKFACTOR);        
+                gtk_box_pack_start (vbox2, button, FALSE, FALSE, UI_PACKFACTOR);
                }
 
              t = g_list_next (t);
@@ -232,4 +238,4 @@ GtkWidget* create_image_browser (gchar *dir)
    gtk_progress_bar_set_fraction (pb, 0);
 
   return wnd;
-}
\ No newline at end of file
+}
