@@ -47,7 +47,7 @@ void ui_update (void)
 
 static gboolean mpb_bounce (gpointer data)
 {
-  gtk_progress_bar_pulse (pb_status);   
+  gtk_progress_bar_pulse (pb_status);
   return TRUE;
 }
 
@@ -56,7 +56,7 @@ void mpb_start (void)
 {
   id_mpb = g_timeout_add (150, mpb_bounce, NULL);
   gtk_widget_show (pb_status);
-  gtk_progress_bar_pulse (pb_status);   
+  gtk_progress_bar_pulse (pb_status);
 }
 
 
@@ -185,7 +185,9 @@ GtkWidget* create_tea_main_window (void)
                               GDK_N, GDK_MOD1_MASK,
                               GTK_ACCEL_VISIBLE);
 
-//  mni_temp = new_menu_item (_("test"), mni_file_menu, on_mni_test);
+  //mni_temp = new_menu_item (_("test"), mni_file_menu, on_mni_test);
+  //mni_temp = new_menu_item (_("test2"), mni_file_menu, on_mni_test2);
+
     
   mni_temp = new_menu_item (_("Crapbook"), mni_file_menu, on_mni_file_crapbook);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
@@ -336,6 +338,10 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Unmark all"), mni_mark_menu, on_mni_unpaint_all);
   mni_temp = new_menu_item (_("Mark each n-th line"), mni_mark_menu, on_mni_mark_each_n_line);
   mni_temp = new_menu_item (_("Mark lines those contains a string"), mni_mark_menu, on_mni_mark_all_lines_with_string);
+  mni_temp = new_menu_item (_("Mark by regexp"), mni_mark_menu, on_mni_mark_on_regexp);
+  mni_temp = new_menu_item (_("Mark all fuzzy and empty translations"), mni_mark_menu, on_mni_mark_lines_with_fuzzy_nontrans);
+
+
 
   mni_temp = new_menu_sep (mni_edit_menu);
 
@@ -371,8 +377,11 @@ GtkWidget* create_tea_main_window (void)
   mni_quest_menu =  new_menu_submenu (mni_temp);
   mni_temp = new_menu_tof (mni_quest_menu);
 
+
+  mni_temp = new_menu_item (_("Find in files"), mni_quest_menu, on_mni_find_in_files);
+
   mni_temp = new_menu_item (_("Search and Replace window"), mni_quest_menu, on_mni_find_and_replace_wnd);
-    
+
   mni_temp = new_menu_item (_("Find"), mni_quest_menu, on_mni_quest_find);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
                               GDK_f, GDK_CONTROL_MASK,
@@ -393,6 +402,9 @@ GtkWidget* create_tea_main_window (void)
                               GDK_F3, GDK_SHIFT_MASK,
                               GTK_ACCEL_VISIBLE);
 
+  mni_temp = new_menu_item (_("Replace"), mni_quest_menu, on_mni_replace_in_place);
+  
+
   mni_temp = new_menu_item (_("Find and mark"), mni_quest_menu, on_mni_search_and_paint);
   mni_temp = new_menu_item (_("Mark lines > n characters"), mni_quest_menu, on_mni_paint_lines_bigger_than);
   
@@ -626,8 +638,25 @@ GtkWidget* create_tea_main_window (void)
 
   mni_temp = new_menu_item (_("Suggest a word"), mni_functions_menu, on_mni_suggest);
 
+
+  
+
   mni_temp = new_menu_sep (mni_functions_menu);
 
+  mni_latex = new_menu_item ("LaTeX", mni_functions_menu, NULL);
+  mni_latex_menu = new_menu_submenu (mni_latex);
+  mni_temp = new_menu_tof (mni_latex_menu);
+
+  mni_temp = new_menu_item (_("Process with LaTeX"), mni_latex_menu, on_mni_latex_process);
+  mni_temp = new_menu_item (_("Process with pdflatex"), mni_latex_menu, on_mni_pdflatex_process);
+
+  mni_temp = new_menu_item (_("dvi to PS"), mni_latex_menu, on_mni_dvi_to_ps);
+  mni_temp = new_menu_item (_("dvi to PDF"), mni_latex_menu, on_mni_dvi_to_pdf);
+  mni_temp = new_menu_item (_("View PDF"), mni_latex_menu, on_mni_view_pdf);
+  mni_temp = new_menu_item (_("View dvi"), mni_latex_menu, on_mni_view_dvi);
+  mni_temp = new_menu_item (_("View PS"), mni_latex_menu, on_mni_view_ps);
+  
+
   mni_ide = new_menu_item (_("IDE"), mni_functions_menu, NULL);
   mni_ide_menu = new_menu_submenu (mni_ide);
   mni_temp = new_menu_tof (mni_ide_menu);
@@ -679,6 +708,9 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item ("XHTML 1.0 Frameset", mni_insert_doctype_menu, on_mni_insert_doctype);
   mni_temp = new_menu_item ("WML 1.1", mni_insert_doctype_menu, on_mni_insert_doctype);
 
+
+
+  mni_temp = new_menu_item (_("Lorem ipsum"), mni_ins_menu, on_mni_lorem_ipsum);
   mni_temp = new_menu_item (_("Date/Time"), mni_ins_menu, on_mni_funx_ins_time);
   mni_temp = new_menu_item (_("Dump menu"), mni_ins_menu, on_mni_dump_menu);
   mni_temp = new_menu_item (_("*Now playing* string from Amarok"), mni_ins_menu, on_mni_ins_np);
@@ -755,6 +787,8 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Convert tabs to spaces"), mni_functions_string_menu, on_mni_tabs_to_spaces);
   mni_temp = new_menu_item (_("Convert spaces to tabs"), mni_functions_string_menu, on_mni_spaces_to_tabs);
   mni_temp = new_menu_item (_("Split to TeX paragraphs"), mni_functions_string_menu, on_mni_split_to_tex_paragraphs);
+  mni_temp = new_menu_item (_("Split by the delimiter"), mni_functions_string_menu, on_mni_split_by);
+  mni_temp = new_menu_item (_("Split after the delimiter"), mni_functions_string_menu, on_mni_split_after_delimiter);
 
   mni_temp = new_menu_item (_("Apply a template to each line"), mni_functions_string_menu, on_mni_func_strings_enclose);
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
@@ -781,18 +815,8 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Encode to Morse code EN"), mni_morse_menu, on_mni_morse_encode);
   mni_temp = new_menu_item (_("Decode from Morse code EN"), mni_morse_menu, on_mni_morse_decode);
 
-  mni_latex = new_menu_item ("LaTeX", menubar1, NULL);
-  mni_latex_menu = new_menu_submenu (mni_latex);
-  mni_temp = new_menu_tof (mni_latex_menu);
+  mni_temp = new_menu_item (_("Last used"), mni_functions_menu, on_mni_repeat_the_last);
 
-  mni_temp = new_menu_item (_("Process with LaTeX"), mni_latex_menu, on_mni_latex_process);
-  mni_temp = new_menu_item (_("Process with pdflatex"), mni_latex_menu, on_mni_pdflatex_process);
-
-  mni_temp = new_menu_item (_("dvi to PS"), mni_latex_menu, on_mni_dvi_to_ps);
-  mni_temp = new_menu_item (_("dvi to PDF"), mni_latex_menu, on_mni_dvi_to_pdf);
-  mni_temp = new_menu_item (_("View PDF"), mni_latex_menu, on_mni_view_pdf);
-  mni_temp = new_menu_item (_("View dvi"), mni_latex_menu, on_mni_view_dvi);
-  mni_temp = new_menu_item (_("View PS"), mni_latex_menu, on_mni_view_ps);
     
   mni_tabs = new_menu_item (_("Tabs"), menubar1, NULL);
   mni_tabs_menu = new_menu_submenu (mni_tabs);
@@ -875,7 +899,7 @@ GtkWidget* create_tea_main_window (void)
   gtk_widget_add_accelerator (mni_temp, "activate", accel_group,
                               GDK_W, GDK_MOD1_MASK,
                               GTK_ACCEL_VISIBLE);
- 
+
   mni_temp = new_menu_item (_("Line numbers"), mni_view_menu, on_mni_view_show_line_numbers);
   mni_temp = new_menu_item (_("Toggle images visibility"), mni_view_menu, on_mni_show_images_in_text);
   mni_temp = new_menu_item ("Imageplane", mni_view_menu, on_mni_imageplane);
@@ -914,8 +938,6 @@ GtkWidget* create_tea_main_window (void)
    
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook1), TRUE);
 
-
-
   gtk_paned_pack1 (GTK_PANED (vpaned1), notebook1, TRUE, TRUE);
   
   vbox2 = gtk_vbox_new (FALSE, UI_PACKFACTOR);
@@ -939,7 +961,7 @@ GtkWidget* create_tea_main_window (void)
   gtk_widget_show (fam_hbox);
   gtk_box_pack_start (GTK_BOX (vbox2), fam_hbox, FALSE, FALSE, UI_PACKFACTOR);
 
-   
+
   ent_search = gtk_entry_new ();   
   gtk_widget_show (ent_search);
   gtk_box_pack_start (GTK_BOX (fam_hbox), ent_search, TRUE, TRUE, UI_PACKFACTOR);
@@ -1020,18 +1042,20 @@ GtkWidget* create_tea_main_window (void)
 
   log_to_memo (_("PLEASE read the manual :)"), NULL, LM_GREET);
   log_to_memo ("<peter.semiletov@gmail.com>", NULL, LM_GREET);
-  log_to_memo ("(C)2000-2005 Peter Semiletov", NULL, LM_GREET);
-  
+  log_to_memo ("(C)2000-2006 Peter Semiletov", NULL, LM_GREET);
+
 #ifdef CHAI_MODE
 
-log_to_memo ("TEA 11.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
+log_to_memo ("TEA 12.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
 
 #else
 
-log_to_memo ("TEA (original) 11.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
+log_to_memo ("TEA (original) 12.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
 
 #endif
-  
+
+
+  mni_last = NULL;
   ui_init ();
 
   gtk_entry_set_text (ent_search, "");  
@@ -1044,5 +1068,17 @@ log_to_memo ("TEA (original) 11.0 @ http://tea.linux.kiev.ua", NULL, LM_GREET);
   if (g_file_test (TEA_PIX_MAINICON, G_FILE_TEST_EXISTS))
      gtk_window_set_default_icon_from_file (TEA_PIX_MAINICON, NULL);
 
+  //g_object_set (G_OBJECT (tag_type),  "font", confile.tag_type_font, NULL);
+ 
+ // g_object_set (G_OBJECT (menubar1), "font-name", "FreeSans 18", NULL);
+  
+  //GtkStyle *stl = gtk_style_new ();
+ // PangoFontDescription *font_desc = pango_font_description_new ();
+  //pango_font_description_set_family
+    //                                        (menubar1->style->font_desc,
+      //                                       "FreeSans 8");
+                                            
+//  gtk_style_attach (stl, tea_main_window);
+
   return tea_main_window;
 }
