@@ -62,7 +62,7 @@ gchar* g_str_replace (const gchar *input, const gchar *replace, const gchar *wit
 {
    gchar *text = g_strdup (input);
    gchar *start = strstr (text, replace);
-    
+
    if (! start)
       return (NULL);
 
@@ -557,32 +557,32 @@ gchar* enc_guess (const gchar *s)
      return NULL;
 
   g_free (enc_guess_value);
-  
+
   if (g_utf8_validate (s, -1, NULL))
      {
       enc_guess_value = g_strdup ("UTF-8");
       return enc_guess_value;
      }
-        
-  if (confile.enc_det_koi8u)
-  if (enc_is_koi8u (s))
-     {
-      enc_guess_value = g_strdup ("KOI8-U");
-      return enc_guess_value;
-     }   
-
-  if (confile.enc_det_koi8r)
-  if (enc_is_koi8r (s))
-     {
-      enc_guess_value = g_strdup ("KOI8-R");
-      return enc_guess_value;
-     }   
 
   if (confile.enc_det_cp1251)
   if (enc_is_cp1251 (s))
      {
       enc_guess_value = g_strdup ("CP1251");
       return enc_guess_value;
+     }
+
+  if (confile.enc_det_koi8u)
+  if (enc_is_koi8u (s))
+     {
+      enc_guess_value = g_strdup ("KOI8-U");
+      return enc_guess_value;
+     }
+
+  if (confile.enc_det_koi8r)
+  if (enc_is_koi8r (s))
+     {
+      enc_guess_value = g_strdup ("KOI8-R");
+      return enc_guess_value;
      }   
 
   if (confile.enc_det_866)
@@ -687,7 +687,7 @@ gchar* str_file_read (const gchar *filename)
   if (! g_file_get_contents (filename, &buf, &length, NULL))
      return NULL;
   else
-      return buf; 
+      return buf;
 } 
 
 
@@ -1367,12 +1367,13 @@ gchar* str_replace_all (gchar *s, gchar *what, gchar *to)
      return g_strdup (s); 
 
   gchar *t = g_str_replace (s, what, to);
+
   gchar *z;
   while (strstr (t, what))
         {
          z = g_str_replace (t, what, to);
          g_free (t);
-         t = z;  
+         t = z;
         }
 
   return t;
@@ -1416,7 +1417,7 @@ GList* glist_repl (GList* list, gchar *format)
 {
   if (! format || ! list)
      return list;
-  
+
   GList *p = g_list_first (list);
   gchar *t = NULL;
 
@@ -1550,16 +1551,16 @@ gchar* str_crackerize (gchar *buf)
   if (! buf)
      return NULL;
 
-  gint32 i;     
+  gint32 i;
   GString* gs = g_string_sized_new (strlen (buf));
-  
+
   gchar *p = buf;
   gunichar u = g_utf8_get_char (p);
 
   while ( u )
         {
-         GRand *r = g_rand_new ();     
-         
+         GRand *r = g_rand_new ();
+
          i = g_rand_int_range (r, 0, 3);
 
          switch (i)
@@ -2261,10 +2262,10 @@ gchar* read_xml_text (gchar *filename, gchar *xml_file, gchar *para)
   gchar *cm = g_strconcat ("unzip -o ", filename, " -d ", confile.tmp_dir, NULL);  
 
   system (cm);
-  
+
   gchar *f = g_strconcat (confile.tmp_dir, G_DIR_SEPARATOR_S, xml_file, NULL);  
   gchar *t = str_file_read (f);
-  
+
   gchar *r = xml_to_plain_text (t, para);
 
   delete_dir (confile.tmp_dir);
@@ -2272,20 +2273,20 @@ gchar* read_xml_text (gchar *filename, gchar *xml_file, gchar *para)
   g_free (f);
   g_free (t);
   return r;
-} 
+}
 
 
 gchar* read_abw_text (gchar *filename, gchar *xml_file, gchar *para)
 {
   if (! filename)
      return NULL;
-  
+
   gchar *t = str_file_read (filename);
   gchar *r = xml_to_plain_text (t, para);
 
   g_free (t);
   return r;
-} 
+}
 
 
 gchar* separated_table_to_latex_tabular (const gchar *st, gchar *sep)
@@ -2515,3 +2516,77 @@ void gslist_strings_free (GSList *list)
   g_slist_free (t);
 }
 
+
+GList* parse_string_to_list_sep (gchar *s, gchar *sep)
+{
+  if (! s)
+     return NULL;
+
+  gchar **a = NULL;
+  GList *result = NULL;
+
+  a = g_strsplit (s, sep, -1);
+  gint c = -1;
+
+  if (a)
+     while (a[++c])
+           result = g_list_prepend (result, g_strdup (a[c])); 
+
+  return g_list_reverse (result);
+}
+
+
+gchar* string_split_by (gchar *source, gchar *delimeter)
+{
+  if (! source || ! delimeter)
+     return NULL;
+
+  if (! strstr (source, delimeter))
+     return NULL;
+
+  GList *l = parse_string_to_list_sep (source, delimeter);
+  gchar *r = string_from_glist (l);
+
+  gslist_strings_free (l);
+  return r;
+}
+
+
+gchar* recent_item_compose (gchar *file_name_utf8, gchar *charset, gint pos)
+{
+  return g_strdup_printf ("%s,%s,%d", file_name_utf8, charset, pos);
+}
+
+
+gchar* tea_convert_charset (gchar *text, gchar *from, gchar *to)
+{
+  gsize bytes_read;
+  gsize bytes_written;
+  GError *error = NULL;
+
+  if (g_utf8_collate (from, CURR_LOCALE) == 0)
+     return (g_locale_to_utf8 (text, strlen (text), &bytes_read, &bytes_written, &error));
+
+  return (g_convert (text, strlen (text), to, from, &bytes_read, &bytes_written, &error));
+}
+
+
+gboolean check_is_number (gchar *value)
+{
+  if (! value)
+     return FALSE;
+
+  gchar *p = value;
+  gunichar u = g_utf8_get_char (p);
+
+  while ( u )
+        {
+         if (! g_unichar_isdigit (u))
+              return FALSE;
+
+         p = g_utf8_next_char (p);
+         u = g_utf8_get_char (p);
+        }
+
+   return TRUE;
+}
\ No newline at end of file
