@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-                                                
+
 gchar* get_file_ver_name (const gchar *name);
 size_t tNumber2Roman (guint uiNumber, int bUpperCase, char *szOutput);
 GList* parse_string_to_list (gchar *s);
@@ -73,3 +73,8 @@ gint glist_get_str_pos (GList *list, gchar *st);
 gchar* copied_from_browser_to_ftext (const gchar *s, const gchar *pattern);
 gchar* get_charset_from_meta (gchar *text);
 void gslist_strings_free (GSList *list);
+GList* parse_string_to_list_sep (gchar *s, gchar *sep);
+gchar* string_split_by (gchar *source, gchar *delimeter);
+gchar* tea_convert_charset (gchar *text, gchar *from, gchar *to);
+gchar* recent_item_compose (gchar *file_name_utf8, gchar *charset, gint pos);
+gboolean check_is_number (gchar *value);
