@@ -249,7 +249,7 @@ void confile_free (void)
 {
   g_free (confile.dir_thumbs);
   g_free (confile.def_file_ext);
-  
+
   g_free (confile.cm_pdflatex);
   g_free (confile.cm_dvi_to_ps);
   g_free (confile.cm_dvi_view); 
@@ -257,7 +257,7 @@ void confile_free (void)
   g_free (confile.cm_ps_view);
   g_free (confile.cm_run_latex);
   g_free (confile.cm_dvi_to_pdf);
-  
+
   g_free (confile.tea_choosed_charsets);
   g_free (confile.def_filesave_charset);
   g_free (confile.tea_kwas_bookmarks);
@@ -265,7 +265,7 @@ void confile_free (void)
   g_free (confile.crapbook_file);
   g_free (confile.snippets_dir);
   g_free (confile.bmx_file);
-  g_free (confile.date_time);                                      
+  g_free (confile.date_time);
   g_free (confile.tea_main_dir);
   g_free (confile.templates_dir);
   g_free (confile.tmp_dir);
@@ -277,13 +277,12 @@ void confile_free (void)
   g_free (confile.default_markup_mode);
   g_free (confile.autosave_file);
   g_free (confile.crash_file);
-    
+
   g_free (confile.tea_recent);
   g_free (confile.tea_hotkeys);
 
   g_free (confile.def_save_dir);
   g_free (confile.def_open_dir);
-  g_free (confile.file_gtkrc);
 
   g_free (confile.cmd_def_doc_browser);
   g_free (confile.color_cursor);
@@ -296,7 +295,7 @@ void confile_free (void)
   g_free (confile.text_background);
   g_free (confile.text_sel_foreground);
   g_free (confile.text_sel_background);
-  
+
 
   g_free (confile.tag_color_lm_error_fg);
   g_free (confile.tag_color_lm_error_bg);
@@ -569,6 +568,7 @@ void tea_start (void)
   gl_notetab_positions = g_list_append (gl_notetab_positions, g_strdup (_("Top")));
   gl_notetab_positions = g_list_append (gl_notetab_positions, g_strdup (_("Bottom")));
 
+  gl_found_files = NULL;
   tooltips = gtk_tooltips_new ();
   gtk_tooltips_enable (tooltips); 
   cur_settings.selected_enc = g_strdup (confile.default_charset);
@@ -592,8 +592,9 @@ void tea_done (void)
         {
          page = p->data;
          page_free (page);
-         page->text_buffer = NULL;
+         page = NULL;
          p = g_list_next (p);
+         //page->text_buffer = NULL;
         }
 
   glist_save_to_file (recent_list, confile.tea_recent);
@@ -604,6 +605,7 @@ void tea_done (void)
   glist_strings_free (bookmarks);
   glist_strings_free (gl_notetab_positions);
   glist_strings_free (gl_image_formats);
+  glist_strings_free (gl_found_files);
 
   if (ht_tea_hotkeys)
      g_hash_table_destroy (ht_tea_hotkeys); 
@@ -612,22 +614,22 @@ void tea_done (void)
      g_hash_table_destroy (ht_entities); 
 
   if (ht_autoreplace)
-     g_hash_table_destroy (ht_autoreplace); 
+     g_hash_table_destroy (ht_autoreplace);
 
-  g_hash_table_destroy (po_t_keywords); 
-  g_hash_table_destroy (bash_t_keywords); 
-  g_hash_table_destroy (php_t_keywords); 
-  g_hash_table_destroy (c_t_keywords); 
-  g_hash_table_destroy (c_t_types); 
-  g_hash_table_destroy (pas_t_keywords); 
+  g_hash_table_destroy (po_t_keywords);
+  g_hash_table_destroy (bash_t_keywords);
+  g_hash_table_destroy (php_t_keywords);
+  g_hash_table_destroy (c_t_keywords);
+  g_hash_table_destroy (c_t_types);
+  g_hash_table_destroy (pas_t_keywords);
   g_hash_table_destroy (pas_t_types);
-  g_hash_table_destroy (py_t_keywords); 
-  
+  g_hash_table_destroy (py_t_keywords);
+
   unlink (confile.tmp_file);
 
   calendar_done ();
-  image_browser_done (); 
-  
+  image_browser_done ();
+
   confile_free ();
 
   if (last_dir)
@@ -640,7 +642,6 @@ void tea_done (void)
   done_hl ();
 
 #endif
-
 }
 
 
@@ -983,7 +984,7 @@ void confile_reload (void)
   confile.snippets_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "snippets", G_DIR_SEPARATOR_S, NULL);
   confile.templates_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "templates", G_DIR_SEPARATOR_S, NULL);
   confile.crapbook_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "crapbook.txt", NULL);
-  confile.file_gtkrc = get_tea_config_file ("gtkrc");
+//  confile.file_gtkrc = get_tea_config_file ("gtkrc");
   confile.dir_thumbs = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".thumbnails", G_DIR_SEPARATOR_S, "normal", NULL);
 
   confile.last_session = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "last_session", NULL); 
@@ -1080,6 +1081,10 @@ else
   confile.common_closing_button_visible = ht_get_int_value ("common_closing_button_visible", 1);
 
 
+
+
+  confile.homeend = ht_get_int_value ("homeend", 0); 
+
   confile.start_with_blank_file = ht_get_int_value ("start_with_blank_file", 0); 
 
   confile.do_last_session = ht_get_int_value ("do_last_session", 0);
@@ -1228,14 +1233,24 @@ void reload_autosave (void)
    gl_autosave = load_file_to_glist (confile.autosave_file);
 }
 
-
+/*
 void write_gtkrc (void)
 {
+#ifdef CHAI_MODE
+
+ gchar *s = g_strconcat ("style \"default\" {\nGtkSourceView::cursor-color = \"", confile.color_cursor, "\"}", NULL);
+
+#else
+
   gchar *s = g_strconcat ("style \"default\" {\nGtkTextView::cursor-color = \"", confile.color_cursor, "\"}", NULL);
+
+
+#endif
+
   save_string_to_file (confile.file_gtkrc, s);
   g_free (s);
 }
-
+*/
 
 void reload_ext_programs (void)
 {
