@@ -61,12 +61,13 @@ typedef struct
   gchar *tmp_file;
   //gchar *user_menu_file;
   gchar *ext_programs;
-  gchar *file_gtkrc;
+  //gchar *file_gtkrc;
 
+  gboolean homeend;
 
   gchar *current_movie;
   gchar *cm_mplayer;
-
+  
   gchar *bmx_file;
   gchar *sessions_dir;
   gchar *tea_rc;
@@ -271,6 +272,7 @@ GHashTable *ht_config;
 GHashTable *ht_autoreplace;
 
 GtkTooltips* tooltips;
+GList *gl_found_files;
 
 gboolean b_exit_flag;
 
