@@ -85,8 +85,8 @@
 #define is_rtf(x) check_ext(x,".rtf")
 #define is_sxw(x) check_ext(x,".sxw")
 #define is_kwd(x) check_ext(x,".kwd")
-#define is_office(x) is_ext(filename,".kwd",".sxw",".abw",NULL)
-#define is_format_readonly(x) is_ext(filename,".kwd",".sxw",".abw",".rtf",".gz",".zip",".bz2",".odt",NULL)
+#define is_office(x) is_ext(x,".kwd",".sxw",".abw",".odt",NULL)
+#define is_format_readonly(x) is_ext(x,".kwd",".sxw",".abw",".rtf",".gz",".zip",".bz2",".odt",NULL)
 
 #define UI_PACKFACTOR 1
 
