@@ -3,7 +3,7 @@
                              -------------------
     begin                : Oct 1 2004
     copyright            : (C) 2004, 2005 by Peter 'Roxton' Semiletov
-    email                : roxton@ua.fm
+    email                : peter.semiletov@gmail.com
 ***************************************************************************/
 
 /*
