@@ -10,6 +10,7 @@
 Copyright (C) 2002 Paolo Maggi
 Copyright (C) 2000 Olivier Sessink
 Copyright (C) 2000  Kh. Naba Kumar Singh
+Copyright (C) 2005 BMPx development team.
 */
 
 /***************************************************************************
@@ -37,6 +38,7 @@ Copyright (C) 2000  Kh. Naba Kumar Singh
 #include <time.h>
 #include <stdio.h>
 
+
 #include "tea_defs.h"
 #include "tea_config.h"
 #include "rox_strings.h"
@@ -62,45 +64,44 @@ gchar* get_time (const gchar* format)
    if (! format)
       return NULL;
 
-  	gchar *out = NULL;
-	gchar *out_utf8 = NULL;
-  	time_t clock;
-  	struct tm *now;
-  	size_t out_length = 0;
-	gchar *locale_format;
+  gchar *out = NULL;
+  gchar *out_utf8 = NULL;
+  time_t clock;
+  struct tm *now;
+  size_t out_length = 0;
+  gchar *locale_format;
 
-	if (strlen (format) == 0)
-		return g_strdup (" ");
+  if (strlen (format) == 0)
+     return g_strdup (" ");
 
-	locale_format = g_locale_from_utf8 (format, -1, NULL, NULL, NULL);
+  locale_format = g_locale_from_utf8 (format, -1, NULL, NULL, NULL);
 
-	if (! locale_format)
-		return g_strdup (" ");
+  if (! locale_format)
+     return g_strdup (" ");
 
-  	clock = time (NULL);
-  	now = localtime (&clock);
+  clock = time (NULL);
+  now = localtime (&clock);
 
-	do
-	{
-		out_length += 255;
-		out = g_realloc (out, out_length);
-	}
-  	while (strftime (out, out_length, locale_format, now) == 0);
+  do
+    {
+     out_length += 255;
+     out = g_realloc (out, out_length);
+    }
+  while (strftime (out, out_length, locale_format, now) == 0);
 
-	g_free (locale_format);
+  g_free (locale_format);
 
-	if (g_utf8_validate (out, -1, NULL))
-		out_utf8 = out;
-	else
-	{
-		out_utf8 = g_locale_to_utf8 (out, -1, NULL, NULL, NULL);
-		g_free (out);
+  if (g_utf8_validate (out, -1, NULL))
+     out_utf8 = out;
+  else
+      {
+       out_utf8 = g_locale_to_utf8 (out, -1, NULL, NULL, NULL);
+       g_free (out);
+       if (! out_utf8)
+          out_utf8 = g_strdup (" ");
+      }
 
-		if (! out_utf8)
-			out_utf8 = g_strdup (" ");
-	}
-
-  	return out_utf8;
+  return out_utf8;
 }
 
 
@@ -712,7 +713,7 @@ gchar* get_lang_name (void)
      return g_strdup ("UTF-8"); 
 
   return g_strndup (g_getenv ("LANG"), 2);
-}  
+}
 
 
 gchar* find_good_browser (void)
@@ -747,9 +748,9 @@ gchar* compose_browser_cmd (gchar *filename)
          t = rep_all_s (confile.cmd_def_doc_browser, filename); 
       return t;
      }
-  
+
   b = find_good_browser ();
-  
+
   if (! b)
      return NULL;
 
@@ -763,19 +764,19 @@ gchar* compose_browser_cmd (gchar *filename)
 gchar* get_tea_doc_compose_name (gchar *f)
 {
   return g_strconcat (TEA_DOC_DIR, f, NULL);
-} 
+}
 
 
 gchar* find_doc_index_name (void)
 {
   gchar *l = get_lang_name ();
 
-  gchar *f = g_strconcat (TEA_DOC_DIR, l, "/index.html", NULL);
+  gchar *f = g_strconcat (TEA_DOC_DIR, l, G_DIR_SEPARATOR_S, "index.html", NULL);
 
   if (! g_file_test (f, G_FILE_TEST_EXISTS))
      {
       g_free (f);
-      f = g_strconcat (TEA_DOC_DIR, "en/index.html", NULL);
+      f = g_strconcat (TEA_DOC_DIR, "en", G_DIR_SEPARATOR_S, "index.html", NULL);
       g_free (l);
       return f;
      }
@@ -1301,3 +1302,74 @@ gboolean has_ext (gchar *filename)
 {
   return (strstr (++filename, "."));
 }
+
+/*
+
+from 
+/*  BMPx - The Dumb Music Player
+ *  Copyright (C) 2005 BMPx development team.
+*/
+
+
+gboolean
+dir_foreach (const gchar    *path,
+             DirForeachFunc  function,
+	     gpointer        user_data,
+             GError        **error)
+{
+  GDir *dir;
+  const gchar *entry;
+  gchar *entry_fullpath;
+
+  if (!(dir = g_dir_open (path, 0, error)))
+    return FALSE;
+
+  while ((entry = g_dir_read_name (dir)))
+    {
+      entry_fullpath = g_build_filename (path, entry, NULL);
+
+      if ((*function) (entry_fullpath, entry, user_data))
+        {
+          g_free (entry_fullpath);
+          break;
+        }
+
+      g_free (entry_fullpath);
+    }
+
+  g_dir_close (dir);
+
+  return TRUE;
+}
+
+
+gboolean cbf_listdir (const gchar *path, const gchar *basename, gpointer  user_data)
+{
+  GError *error = NULL;
+
+  if (g_file_test (path, G_FILE_TEST_IS_DIR))
+      {
+       dir_foreach (path, cbf_listdir, user_data, &error);
+       return FALSE;
+      }
+
+  if (g_pattern_match_simple (user_data, path))
+      gl_found_files = g_list_prepend (gl_found_files, g_strdup (path));
+
+ /*
+  while (gtk_events_pending ())
+          gtk_main_iteration ();
+
+*/
+
+  return FALSE;
+}
+
+
+void read_dir_files_recurse (gchar *path, gchar *pattern)
+{
+  glist_strings_free (gl_found_files);
+  gl_found_files = NULL;
+  GError *error = NULL;
+  dir_foreach (path, cbf_listdir, pattern, &error);
+}
