@@ -15,6 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
+
+
+typedef gboolean (*DirForeachFunc) (const gchar *path,
+				    const gchar *basename,
+				    gpointer     user_data);
+
+
 gchar* get_noname_name (void);
 
 int get_value (int total, int perc);
@@ -62,3 +69,5 @@ gboolean check_ext_wo_dot (gchar *filename, gchar *ext);
 gboolean is_writable (gchar *filename);
 gboolean is_readable (gchar *filename);
 gboolean has_ext (gchar *filename);
+gboolean dir_foreach (const gchar *path, DirForeachFunc function, gpointer user_data, GError **error);
+void read_dir_files_recurse (gchar *path, gchar *pattern);
