@@ -81,15 +81,13 @@ GtkWidget* tea_color_selector (GtkWidget *container, gchar *caption, gchar *valu
   gtk_widget_show (x);
   gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
 
-  x = gtk_entry_new ();   
+  x = gtk_entry_new ();
   gtk_widget_show (x);
   gtk_box_pack_start (b, x, TRUE, TRUE, UI_PACKFACTOR);
 
   if (value)
      gtk_entry_set_text (x, value);
-
-  gtk_entry_set_editable (x, FALSE);
-
+  
   GdkColor color;
   gdk_color_parse (value, &color);
 
@@ -180,6 +178,33 @@ static void cb_select_dir (GtkObject *object, GtkWidget *w)
 }
 
 
+static void cb_select_dir2 (GtkObject *object, GtkWidget *w) 
+{
+  gchar *dir;
+  gchar *t;
+  GtkEntry *e = w;
+  GtkWidget *dialog = gtk_file_chooser_dialog_new (_("Select a directory"),
+                                                   NULL,
+                                                   GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                                   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                                   NULL);
+
+  if (g_file_test (gtk_entry_get_text (e), G_FILE_TEST_EXISTS)) 
+      gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
+                                           gtk_entry_get_text (e));
+
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+    {
+     dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog));
+     gtk_entry_set_text (e, dir);  
+     g_free (dir);
+    }
+
+  gtk_widget_destroy (dialog);
+}
+
+
 GtkWidget* tea_dir_selector (GtkWidget *container, gchar *caption, gchar *value)
 {
   GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
@@ -197,13 +222,39 @@ GtkWidget* tea_dir_selector (GtkWidget *container, gchar *caption, gchar *value)
   if (value)
      gtk_entry_set_text (x, value);
 
-  gtk_entry_set_editable (x, FALSE);
+//  gtk_entry_set_editable (x, FALSE);
 
   GtkWidget *bt = tea_stock_button (GTK_STOCK_OPEN);
   gtk_widget_show (bt);
   gtk_box_pack_start (b, bt, FALSE, FALSE, UI_PACKFACTOR);
   g_signal_connect (bt, "clicked", G_CALLBACK (cb_select_dir), x);
-  
+
+  return x;
+}
+
+
+GtkWidget* tea_dir_selector2 (GtkWidget *container, gchar *caption, gchar *value)
+{
+  GtkWidget *b = gtk_hbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (b);
+  gtk_box_pack_start (container, b, FALSE, TRUE, UI_PACKFACTOR);
+
+  GtkWidget *x = gtk_label_new (caption);  
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, FALSE, FALSE, UI_PACKFACTOR);
+
+  x = gtk_entry_new ();
+  gtk_widget_show (x);
+  gtk_box_pack_start (b, x, TRUE, TRUE, UI_PACKFACTOR);
+
+  if (value)
+     gtk_entry_set_text (x, value);
+
+  GtkWidget *bt = tea_stock_button (GTK_STOCK_OPEN);
+  gtk_widget_show (bt);
+  gtk_box_pack_start (b, bt, FALSE, FALSE, UI_PACKFACTOR);
+  g_signal_connect (bt, "clicked", G_CALLBACK (cb_select_dir2), x);
+
   return x;
 }
 
@@ -793,3 +844,10 @@ GtkWidget* tea_color_selector_simple (GtkWidget *container, gchar *caption)
   
   return bt;
 }
+
+gchar* get_gtk_ver (void)
+{
+   return g_strdup_printf ("%d.%d.%d", gtk_major_version, gtk_minor_version, gtk_micro_version);
+} 
+
+
