@@ -400,6 +400,9 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
  
    l = add_to_glist_combined_str (l, "text_sel_foreground", gtk_entry_get_text (GTK_ENTRY (ent_text_sel_foreground)));
    l = add_to_glist_combined_str (l, "text_sel_background", gtk_entry_get_text (GTK_ENTRY (ent_text_sel_background)));
+   l = add_to_glist_combined_str (l, "", gtk_entry_get_text (GTK_ENTRY (ent_color_cursor)));
+
+
 
    l = add_to_glist_combined_str (l, "def_filesave_charset", gtk_entry_get_text (GTK_ENTRY (ent_def_filesave_charset)));
    l = add_to_glist_combined_str (l, "default_charset", gtk_entry_get_text (GTK_ENTRY (ent_default_charset)));
@@ -446,6 +449,10 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "add_def_file_ext", gtk_toggle_button_get_active (&cb_add_def_file_ext->toggle_button));
    
 
+
+
+    l = add_to_glist_combined_int (l, "homeend", gtk_toggle_button_get_active (&cb_homeend->toggle_button));
+   
    l = add_to_glist_combined_int (l, "do_hl_on_fileopen", gtk_toggle_button_get_active (&cb_do_hl_on_fileopen->toggle_button));
    l = add_to_glist_combined_int (l, "do_backup", gtk_toggle_button_get_active (&cb_do_backup->toggle_button));
 
@@ -499,9 +506,9 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    glist_save_to_file (l, confile.tea_rc);
    glist_strings_free (l);
    confile_reload ();
-   write_gtkrc (); 
-   gtk_rc_parse (confile.file_gtkrc);
-   gtk_rc_reset_styles (gtk_settings_get_for_screen (gdk_screen_get_default ()));
+//   write_gtkrc (); 
+//   gtk_rc_parse (confile.file_gtkrc);
+//   gtk_rc_reset_styles (gtk_settings_get_for_screen (gdk_screen_get_default ()));
    ui_update ();
    doc_update_all ();
    update_enc_menu();
@@ -891,8 +898,9 @@ static GtkWidget* wnd_options_editor (void)
 #endif
 
   ent_def_markup_mode = tea_combo (page, gl_markup_modes, _("Default markup mode"), confile.default_markup_mode);
-
   sb_tab_size = tea_spinbutton (page, _("Tab size in spaces"), confile.tab_size);
+  cb_homeend = tea_checkbox (page, _("Smart Home/End"), confile.homeend);
+
   cb_ins_spaces_on_tab_press = tea_checkbox (page, _("Insert spaces on TAB key"), confile.ins_spaces_on_tab_press);
   cb_use_auto_indent = tea_checkbox (page, _("Automatic indent"), confile.use_auto_indent);
   cb_do_autorep = tea_checkbox (page, _("Autoreplace"), confile.do_autorep);
@@ -924,11 +932,10 @@ static GtkWidget* wnd_options_paths (void)
   cb_use_def_save_dir = tea_checkbox (page, _("Use default saving directory"), confile.use_def_save_dir);
   ent_def_open_dir = tea_dir_selector (page, _("Default file opening directory"), confile.def_open_dir);
   cb_use_def_open_dir = tea_checkbox (page, _("Use default file opening directory"), confile.use_def_open_dir);
-  
+
   cb_add_def_file_ext = tea_checkbox (page, _("Add this extension to the file which is *Saving as*"), confile.add_def_file_ext);
   ent_def_file_ext = tea_text_entry (page, _("(<i>for example, txt, html, etc</i>)"), confile.def_file_ext);
 
-
   return page;
 }
 
@@ -943,7 +950,7 @@ GtkWidget* wnd_options_create (void)
   gtk_widget_show (vbox1);
   gtk_container_add (GTK_CONTAINER (wnd_options), vbox1);
 
-  GtkWidget *notebook = gtk_notebook_new ();         
+  GtkWidget *notebook = gtk_notebook_new ();
   gtk_notebook_set_tab_pos (notebook, GTK_POS_LEFT);
 
   gtk_widget_show (notebook);
@@ -963,7 +970,7 @@ GtkWidget* wnd_options_create (void)
   gtk_notebook_append_page (notebook, page_fonts, gtk_label_new (_("Fonts")));
 
 #endif
-  
+
   gtk_notebook_append_page (notebook, wnd_options_editor (), gtk_label_new (_("Editor")));
 
 #ifdef CHAI_MODE
@@ -971,7 +978,7 @@ GtkWidget* wnd_options_create (void)
 //n.p. THe Pixies - Manta Ray
 
  gtk_notebook_append_page (notebook, wnd_options_hl_chai (), gtk_label_new (_("Highlighting")));
-  
+
 #endif
 
   gtk_notebook_append_page (notebook, wnd_options_colors (), gtk_label_new (_("Colors")));
@@ -988,7 +995,7 @@ GtkWidget* wnd_options_create (void)
                     G_CALLBACK (on_kwas_notebook_switch_page),
                     NULL);
 
-  GtkWidget *hbox1 = gtk_hbutton_box_new ();     
+  GtkWidget *hbox1 = gtk_hbutton_box_new ();
   gtk_button_box_set_layout (hbox1, GTK_BUTTONBOX_SPREAD);
 
   gtk_widget_show (hbox1);
@@ -1011,13 +1018,13 @@ GtkWidget* wnd_options_create (void)
 
   GtkWidget *bt_apply = gtk_button_new ();
   gtk_container_add (GTK_CONTAINER (bt_apply), hb_apply);
-  
+
   gtk_widget_show (bt_apply);
   gtk_container_add (GTK_CONTAINER (hbox1), bt_apply);
 
   g_signal_connect (bt_apply, "clicked", G_CALLBACK (cb_on_bt_apply), wnd_options);
 
-  gtk_window_set_position (wnd_options, GTK_WIN_POS_CENTER);   
+  gtk_window_set_position (wnd_options, GTK_WIN_POS_CENTER);
   gtk_window_set_modal (wnd_options, TRUE);
 
   g_signal_connect (G_OBJECT (wnd_options), "key_press_event", G_CALLBACK (win_key_handler), wnd_options);
