@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
+//#include <fcntl.h>
 
 #ifdef CHAI_MODE
 
@@ -26,7 +27,6 @@
 GtkSourceLanguagesManager *source_languages_manager;  
 GtkSourceTagTable *main_tags_table;
 
-
 #else
 
 GtkTextTagTable *main_tags_table;
@@ -35,8 +35,6 @@ GtkTextTagTable *main_tags_table;
 
 GtkTextTag *tag_paint;
 GtkTextTag *tag_current_line;
-
-
 GtkTextTag *tag_spell_err;
 GtkTextTag *tag_comment;
 GtkTextTag *tag_identifier;
@@ -46,25 +44,23 @@ GtkTextTag *tag_html_tag;
 GtkTextTag *tag_preprocessor;
 GtkTextTag *tag_type;
 
-
 GHashTable *c_t_keywords;
 GHashTable *c_t_types;
-
 GHashTable *pas_t_keywords;
 GHashTable *pas_t_types;
-
 GHashTable *py_t_keywords;
-
 GHashTable *php_t_keywords;
 GHashTable *bash_t_keywords;
 GHashTable *po_t_keywords;
 
 
- 
 typedef struct
 {
   gpointer um;
 
+//  struct flock lock;
+//  int fd;
+
   gboolean autosave;
   gboolean toggle_images_visibility;
 
@@ -80,17 +76,14 @@ typedef struct
   gchar *file_name_local;
   gchar *encoding;
   gboolean linenums;
-  
-  
-#ifdef CHAI_MODE
 
+
+#ifdef CHAI_MODE
   GtkSourceBuffer *text_buffer;
 #else
-
   GtkTextBuffer *text_buffer;
-
 #endif
-  
+
   GtkWidget *tab_label;
   GtkWidget *but;
 
@@ -145,7 +138,6 @@ void save_tag (GtkSourceLanguage *language, GtkSourceTag *tag);
 void do_backup (gchar *file_name, gboolean do_check);
 
 t_note_page* doc_clear_new (void);
-                                        
 t_note_page* page_create_new (void);
 void page_free (t_note_page *page);
 void page_del_by_index (int i);
@@ -158,12 +150,10 @@ t_note_page* doc_open_file (gchar *a_filename);
 //cur_text_doc points to current text document (in any case)
 t_note_page *cur_text_doc;
 
-
 gboolean doc_is_sel (gpointer text_buffer);
 gchar* doc_get_buf (gpointer text_buffer);
 gboolean doc_save_buffer_to_file (gpointer text_buffer, gchar *filename);
 
-
 void doc_select_line (t_note_page *doc, gint line);
 void doc_rep_sel (t_note_page *page, const gchar *newstring);
 t_note_page* get_page (void);
@@ -173,7 +163,6 @@ void document_set_line_numbers(t_note_page* doc, gboolean value);
 void doc_update_all (void);
 gint editor_get_pos (t_note_page *doc);
 void editor_set_pos (t_note_page *doc, guint pos);
-//gchar* doc_get_word (t_note_page *doc);
 void log_to_memo (gchar *m1, gchar* m2, gint mode);
 void widget_apply_colors (GtkWidget *w);
 gboolean doc_reload_text (t_note_page *doc, gchar *filename, gchar *enc);
@@ -184,13 +173,13 @@ t_note_page* doc_ins_to_new (const gchar *newstring);
 t_note_page* get_page_text (void);
 void set_title (t_note_page *t);
 t_note_page* open_file_std (gchar *f);
-gboolean doc_search_f_next_ncase (t_note_page *doc); 
-gboolean doc_search_f_ncase (t_note_page *doc, const gchar *text); 
+gboolean doc_search_f_next_ncase (t_note_page *doc);
+gboolean doc_search_f_ncase (t_note_page *doc, const gchar *text);
 gchar* upcase_each_first_letter_ofw (t_note_page *doc);
 gchar* doc_get_word_at_left (t_note_page *doc, GtkTextIter *itstart, GtkTextIter *itend); 
-void doc_move_cursor_backw (t_note_page *doc, gint i); 
-void doc_move_cursor_forw (t_note_page *doc, gint i); 
-void doc_move_cursor_backw_middle_tags (t_note_page *doc); 
+void doc_move_cursor_backw (t_note_page *doc, gint i);
+void doc_move_cursor_forw (t_note_page *doc, gint i);
+void doc_move_cursor_backw_middle_tags (t_note_page *doc);
 
 void indent_real(GtkWidget *text_view);
 void doc_header_source_switch (t_note_page *doc);
@@ -212,18 +201,14 @@ void doc_undo (t_note_page *doc);
 void doc_redo (t_note_page *doc);
 void doc_indent_selection (t_note_page *doc, gboolean unindent);
 void doc_save_emergency (void);
-gchar* get_c_url2 (t_note_page *doc); 
+gchar* get_c_url2 (t_note_page *doc);
 gchar* doc_get_cur_mispelled (t_note_page *doc, GtkTextIter *itstart, GtkTextIter *itend); 
 void hide_error_marks (t_note_page *doc);
 
 
-
-
-
 GtkTextTag *tag_paint;
 GtkTextTag *tag_current_line;
 
-
 GtkTextTag *tag_spell_err;
 GtkTextTag *tag_comment;
 GtkTextTag *tag_identifier;
@@ -236,12 +221,9 @@ GtkTextTag *tag_type;
 
 GHashTable *c_t_keywords;
 GHashTable *c_t_types;
-
 GHashTable *pas_t_keywords;
 GHashTable *pas_t_types;
-
 GHashTable *py_t_keywords;
-
 GHashTable *php_t_keywords;
 GHashTable *bash_t_keywords;
 GHashTable *po_t_keywords;
@@ -251,4 +233,17 @@ GHashTable *po_t_keywords;
 
 void document_apply_hl (t_note_page* doc); 
 
-#endif
\ No newline at end of file
+#endif
+
+void doc_set_text (t_note_page *doc, const gchar *text);
+gchar* doc_get_sel (t_note_page *doc);
+gboolean doc_replace_from_cursor_ones (t_note_page *doc, const gchar *what_to_find, const gchar *replace_to,
+                                       gboolean undoable);
+void doc_replace_from_cursor_all (t_note_page *doc, const gchar *what_to_find, const gchar *replace_to);
+gchar* doc_get_current_word (t_note_page *doc, GtkTextIter *itstart, GtkTextIter *itend);
+gchar* doc_move_to_next_word (t_note_page *doc);
+void modify_cursor_color (GtkWidget *textview, gchar *color_name);
+void doc_smarthomeend (t_note_page *doc, GdkEventKey *event);
+gboolean doc_move_to_next_word_sel_if_regexp (t_note_page *doc, gchar *text);
+//void doc_lock_file (t_note_page *doc);
+//void doc_unlock_file (t_note_page *doc);
