@@ -50,14 +50,14 @@ GList* tv_get_selected_multiply (GtkTreeView *tree_view)
 {
   if (tv_temp_list)
      g_list_free (tv_temp_list);
-  
-  tv_temp_list = NULL;  
+
+  tv_temp_list = NULL;
 
   GtkTreeSelection *sl = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
-  
+
   if (gtk_tree_selection_get_mode (sl) != GTK_SELECTION_MULTIPLE)
      return NULL;
-  
+
   gtk_tree_selection_selected_foreach (sl, tv_simple_cb, NULL);
 
   return g_list_reverse (tv_temp_list);
@@ -162,3 +162,31 @@ GtkTreeView* tv_create_framed (GtkContainer *c, gchar *caption, GtkSelectionMode
 
   return tv;
 }
+
+
+
+static gboolean cb_listitems   (GtkTreeModel *model,
+                                             GtkTreePath *path,
+                                             GtkTreeIter *iter,
+                                             gpointer data)
+{
+  gchar *name;
+  gtk_tree_model_get (model, iter, COL_TEXT, &name, -1);
+  tv_temp_list = g_list_prepend (tv_temp_list, name);
+
+  return FALSE;
+}
+
+
+GList* tv_get_list_data (GtkTreeView *tree_view) 
+{
+  if (tv_temp_list)
+     g_list_free (tv_temp_list);
+
+  tv_temp_list = NULL; 
+
+  GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (tree_view));
+  gtk_tree_model_foreach (GTK_TREE_MODEL (model), cb_listitems, NULL);
+
+  return g_list_reverse (tv_temp_list);
+}
